==> ejc-guarantee-api-3.0.0-20230420.093508-21-sources.jar: com/ejianc/business/guarantee/contract/vo/FinanceVO.java <==
package com.ejianc.business.guarantee.contract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 合同财务确认信息
 * 
 * @author generator
 * 
 */
public class FinanceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String financeRemark; // 备注
    private BigDecimal financeMny; // 保费金额
    private Integer financeReceive; // 保费是否到账(1-是 2-否)
    private Long contractId; // 合同id
    private BigDecimal financeReturnMny; // 反担保金额
    private Integer financeReturnReceive; // 反担保金额是否到账(1-是 2-否)
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getFinanceRemark() {
        return financeRemark;
    }

    public void setFinanceRemark(String financeRemark) {
        this.financeRemark = financeRemark;
    }

    public BigDecimal getFinanceMny() {
        return financeMny;
    }

    public void setFinanceMny(BigDecimal financeMny) {
        this.financeMny = financeMny;
    }
    public Integer getFinanceReceive() {
        return financeReceive;
    }

    public void setFinanceReceive(Integer financeReceive) {
        this.financeReceive = financeReceive;
    }
    @ReferSerialTransfer(referCode="ref-guarantee-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public BigDecimal getFinanceReturnMny() {
        return financeReturnMny;
    }

    public void setFinanceReturnMny(BigDecimal financeReturnMny) {
        this.financeReturnMny = financeReturnMny;
    }
    public Integer getFinanceReturnReceive() {
        return financeReturnReceive;
    }

    public void setFinanceReturnReceive(Integer financeReturnReceive) {
        this.financeReturnReceive = financeReturnReceive;
    }
    
}

==> ejc-guarantee-api-3.0.0-20230421.035612-23-sources.jar: com/ejianc/business/guarantee/contract/vo/FinanceVO.java <==
package com.ejianc.business.guarantee.contract.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 合同财务确认信息
 * 
 * @author generator
 * 
 */
public class FinanceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String financeRemark; // 备注
    private BigDecimal financeMny; // 保费金额
    private Integer financeReceive; // 保费是否到账(1-是 2-否)
    private Long contractId; // 合同id
    private String contractName; // 合同名称
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private BigDecimal financeReturnMny; // 反担保金额
    private Integer financeReturnReceive; // 反担保金额是否到账(1-是 2-否)
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getFinanceRemark() {
        return financeRemark;
    }

    public void setFinanceRemark(String financeRemark) {
        this.financeRemark = financeRemark;
    }

    public BigDecimal getFinanceMny() {
        return financeMny;
    }

    public void setFinanceMny(BigDecimal financeMny) {
        this.financeMny = financeMny;
    }
    public Integer getFinanceReceive() {
        return financeReceive;
    }

    public void setFinanceReceive(Integer financeReceive) {
        this.financeReceive = financeReceive;
    }
    @ReferSerialTransfer(referCode="ref-guarantee-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public BigDecimal getFinanceReturnMny() {
        return financeReturnMny;
    }

    public void setFinanceReturnMny(BigDecimal financeReturnMny) {
        this.financeReturnMny = financeReturnMny;
    }
    public Integer getFinanceReturnReceive() {
        return financeReturnReceive;
    }

    public void setFinanceReturnReceive(Integer financeReturnReceive) {
        this.financeReturnReceive = financeReturnReceive;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
